@@ -1,15 +1,16 @@
-/* deviceconfig.h -- This file is part of Archimedes release 0.0.2.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+/* deviceconfig.h -- This file is part of Archimedes release 0.1.0.
+   Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements both the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+   of effective potential method. It is now able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
    Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -18,14 +19,13 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 // ######################################################
 // Created on 05 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 16 Mar.2005, Siracusa, J.M.Sellier
+// Last modif. : 10 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Initial Configuration of the Particles (electrons)
@@ -58,20 +58,22 @@ MCdevice_config(void)
 // We assume that the particles are initially 
 // at near thermal equilibrium
 
-// In the case of GaAs, 80% of the electrons are considered in the Gamma
+// In the case of two-valleys materials, 80% of the electrons are considered in the Gamma
 // valley in the starting simulation time, while the other 20% are
 // in the L-valley.
       if(leid_flag==0){
        IV=1;
        c1=log(rnd());
-       if(Material==SILICON) 
-        c2=SMH[0]*sqrt(-1.5*BKTQ*c1*(1.-alphaSILICON*1.5*BKTQ*c1));
-       if(Material==GAAS){
+       if(NOVALLEY[i_dom[i][j]]==1) 
+        c2=SMH[i_dom[i][j]][0]*sqrt(-1.5*BKTQ*c1*(1.-alphaK[i_dom[i][j]][1]*1.5*BKTQ*c1));
+       if(NOVALLEY[i_dom[i][j]]==2){
+// 80% of the created particles goes in the first valley
         IV=1;
-        c2=SMH[IV]*sqrt(-1.5*BKTQ*c1*(1.-alphaGAAS*1.5*BKTQ*c1));
+        c2=SMH[i_dom[i][j]][IV]*sqrt(-1.5*BKTQ*c1*(1.-alphaK[i_dom[i][j]][1]*1.5*BKTQ*c1));
+// 20% of the created particles goes in the second valley
         if(rnd()>0.8){
          IV=2;
-         c2=SMH[IV]*sqrt(-1.5*BKTQ*c1*(1.-alpha2GAAS*1.5*BKTQ*c1));
+         c2=SMH[i_dom[i][j]][IV]*sqrt(-1.5*BKTQ*c1*(1.-alphaK[i_dom[i][j]][2]*1.5*BKTQ*c1));
         }
        }
       }
@@ -82,14 +84,14 @@ MCdevice_config(void)
 // loaded from precedent simulations and have nothing to 
 // do with the lattice energy.
        c1=-u2d[i][j][4]/u2d[i][j][1]/Q;
-       if(Material==SILICON) 
-        c2=SMH[0]*sqrt(-1.5*c1*(1.-alphaSILICON*1.5*c1));
-       if(Material==GAAS){
+       if(NOVALLEY[i_dom[i][j]]==1) 
+        c2=SMH[i_dom[i][j]][0]*sqrt(-1.5*c1*(1.-alphaK[i_dom[i][j]][1]*1.5*c1));
+       if(NOVALLEY[i_dom[i][j]]==2){
         IV=1;
-        c2=SMH[IV]*sqrt(-1.5*c1*(1.-alphaGAAS*1.5*c1));
+        c2=SMH[i_dom[i][j]][IV]*sqrt(-1.5*c1*(1.-alphaK[i_dom[i][j]][1]*1.5*c1));
         if(rnd()>0.8){
          IV=2;
-         c2=SMH[IV]*sqrt(-1.5*c1*(1.-alpha2GAAS*1.5*c1));
+         c2=SMH[i_dom[i][j]][IV]*sqrt(-1.5*c1*(1.-alphaK[i_dom[i][j]][2]*1.5*c1));
         }
        }
       }
@@ -102,7 +104,7 @@ MCdevice_config(void)
       P[n][1]=c2*c3*c6;
       P[n][2]=c2*c4*c6;
       P[n][3]=c2*c7;
-      P[n][4]=-log(rnd())/GM;
+      P[n][4]=-log(rnd())/GM[i_dom[i][j]];
       P[n][5]=dx*(rnd()+(real)(i)-1.5);
       P[n][6]=dy*(rnd()+(real)(j)-1.5);
       if(i==1) P[n][5]=dx*0.5*rnd();
